@@ -94,6 +94,12 @@ def parse_args():
              "smaller number of workers you may want use larger value."
              .format(client.BUFFER_SIZE))
 
+    parser.add_argument(
+        "--timeout-policy",
+        choices=('legacy', 'pause', 'cancel'),
+        default='cancel',
+        help="The action to be made for a timed out transfer")
+
     return parser.parse_args()
 
 
@@ -233,7 +239,8 @@ progress("Creating image transfer...")
 host = imagetransfer.find_host(connection, args.sd_name)
 
 transfer = imagetransfer.create_transfer(connection, disk,
-    types.ImageTransferDirection.UPLOAD, host=host)
+    types.ImageTransferDirection.UPLOAD, host=host,
+    timeout_policy=types.ImageTransferTimeoutPolicy(args.timeout_policy))
 
 progress("Transfer ID: %s" % transfer.id)
 progress("Transfer host name: %s" % transfer.host.name)
